summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorDianne Hackborn <hackbod@google.com>2014-10-08 22:48:44 +0000
committerAndroid Git Automerger <android-git-automerger@android.com>2014-10-08 22:48:44 +0000
commit529b78941c20c2b45312eeedbd509d0ded4f7323 (patch)
tree1aff9a9aac271e48dec04cb986c5cadc5f4105e9
parent511925c9e143ebc6eeb0efdf433cc0519b5e5eb1 (diff)
parent89b196958fee07475765bd3c458098464ba16f2e (diff)
downloadframeworks_base-529b78941c20c2b45312eeedbd509d0ded4f7323.zip
frameworks_base-529b78941c20c2b45312eeedbd509d0ded4f7323.tar.gz
frameworks_base-529b78941c20c2b45312eeedbd509d0ded4f7323.tar.bz2
am 89b19695: Merge "Put in real "code" (aka marketing) name." into lmp-dev
* commit '89b196958fee07475765bd3c458098464ba16f2e': Put in real "code" (aka marketing) name.
-rw-r--r--api/current.txt1
-rw-r--r--core/java/android/app/ActivityManager.java4
-rw-r--r--core/java/android/app/ContextImpl.java3
-rw-r--r--core/java/android/app/Fragment.java2
-rw-r--r--core/java/android/app/Notification.java2
-rw-r--r--core/java/android/content/Context.java4
-rw-r--r--core/java/android/content/Intent.java2
-rw-r--r--core/java/android/hardware/location/GeofenceHardware.java2
-rw-r--r--core/java/android/os/Build.java15
-rw-r--r--core/java/android/os/Message.java2
-rw-r--r--core/java/android/os/UserManager.java3
-rw-r--r--core/java/android/provider/MediaStore.java6
-rw-r--r--core/java/android/service/notification/NotificationListenerService.java4
-rw-r--r--core/java/android/view/WindowManagerGlobal.java2
-rw-r--r--core/java/android/webkit/CookieManager.java3
-rw-r--r--core/java/android/webkit/WebSettings.java4
-rw-r--r--core/java/android/webkit/WebView.java3
-rw-r--r--core/java/android/widget/Editor.java3
-rw-r--r--core/java/android/widget/Spinner.java4
-rw-r--r--core/java/com/android/internal/app/ResolverActivity.java3
-rw-r--r--graphics/java/android/graphics/BitmapFactory.java4
-rw-r--r--graphics/java/android/graphics/Picture.java2
-rw-r--r--graphics/java/android/graphics/drawable/ColorDrawable.java2
-rw-r--r--location/java/android/location/LocationManager.java2
-rw-r--r--packages/SystemUI/src/com/android/systemui/statusbar/BaseStatusBar.java6
-rw-r--r--policy/src/com/android/internal/policy/impl/PhoneWindow.java2
-rwxr-xr-xservices/core/java/com/android/server/am/ActiveServices.java3
-rw-r--r--services/core/java/com/android/server/dreams/DreamManagerService.java2
-rw-r--r--services/core/java/com/android/server/notification/ManagedServices.java4
29 files changed, 49 insertions, 50 deletions
diff --git a/api/current.txt b/api/current.txt
index 17c9dcc..1b07af9 100644
--- a/api/current.txt
+++ b/api/current.txt
@@ -21400,6 +21400,7 @@ package android.os {
field public static final int KITKAT = 19; // 0x13
field public static final int KITKAT_WATCH = 20; // 0x14
field public static final int L = 21; // 0x15
+ field public static final int LOLLIPOP = 21; // 0x15
}
public final class Bundle extends android.os.BaseBundle implements java.lang.Cloneable android.os.Parcelable {
diff --git a/core/java/android/app/ActivityManager.java b/core/java/android/app/ActivityManager.java
index 84a7f5d..2cd7379 100644
--- a/core/java/android/app/ActivityManager.java
+++ b/core/java/android/app/ActivityManager.java
@@ -930,7 +930,7 @@ public class ActivityManager {
* same time, assumptions made about the meaning of the data here for
* purposes of control flow will be incorrect.</p>
*
- * @deprecated As of {@link android.os.Build.VERSION_CODES#L}, this method is
+ * @deprecated As of {@link android.os.Build.VERSION_CODES#LOLLIPOP}, this method is
* no longer available to third party applications: the introduction of
* document-centric recents means
* it can leak personal information to the caller. For backwards compatibility,
@@ -1216,7 +1216,7 @@ public class ActivityManager {
* same time, assumptions made about the meaning of the data here for
* purposes of control flow will be incorrect.</p>
*
- * @deprecated As of {@link android.os.Build.VERSION_CODES#L}, this method
+ * @deprecated As of {@link android.os.Build.VERSION_CODES#LOLLIPOP}, this method
* is no longer available to third party
* applications: the introduction of document-centric recents means
* it can leak person information to the caller. For backwards compatibility,
diff --git a/core/java/android/app/ContextImpl.java b/core/java/android/app/ContextImpl.java
index e9340eb..7fafc38 100644
--- a/core/java/android/app/ContextImpl.java
+++ b/core/java/android/app/ContextImpl.java
@@ -148,7 +148,6 @@ import android.app.trust.TrustManager;
import com.android.internal.annotations.GuardedBy;
import com.android.internal.app.IAppOpsService;
import com.android.internal.os.IDropBoxManagerService;
-import com.android.internal.telecom.ITelecomService;
import java.io.File;
import java.io.FileInputStream;
@@ -1671,7 +1670,7 @@ class ContextImpl extends Context {
private void validateServiceIntent(Intent service) {
if (service.getComponent() == null && service.getPackage() == null) {
- if (getApplicationInfo().targetSdkVersion >= Build.VERSION_CODES.L) {
+ if (getApplicationInfo().targetSdkVersion >= Build.VERSION_CODES.LOLLIPOP) {
IllegalArgumentException ex = new IllegalArgumentException(
"Service Intent must be explicit: " + service);
throw ex;
diff --git a/core/java/android/app/Fragment.java b/core/java/android/app/Fragment.java
index c49012b..ab28d95 100644
--- a/core/java/android/app/Fragment.java
+++ b/core/java/android/app/Fragment.java
@@ -1124,7 +1124,7 @@ public class Fragment implements ComponentCallbacks2, OnCreateContextMenuListene
*/
public LayoutInflater getLayoutInflater(Bundle savedInstanceState) {
// Newer platform versions use the child fragment manager's LayoutInflaterFactory.
- if (mActivity.getApplicationInfo().targetSdkVersion >= Build.VERSION_CODES.L) {
+ if (mActivity.getApplicationInfo().targetSdkVersion >= Build.VERSION_CODES.LOLLIPOP) {
LayoutInflater result = mActivity.getLayoutInflater().cloneInContext(mActivity);
getChildFragmentManager(); // Init if needed; use raw implementation below.
result.setPrivateFactory(mChildFragmentManager.getLayoutInflaterFactory());
diff --git a/core/java/android/app/Notification.java b/core/java/android/app/Notification.java
index 4b3aefe..fb10e17 100644
--- a/core/java/android/app/Notification.java
+++ b/core/java/android/app/Notification.java
@@ -1948,7 +1948,7 @@ public class Notification implements Parcelable
mPriority = PRIORITY_DEFAULT;
mPeople = new ArrayList<String>();
- mColorUtil = context.getApplicationInfo().targetSdkVersion < Build.VERSION_CODES.L ?
+ mColorUtil = context.getApplicationInfo().targetSdkVersion < Build.VERSION_CODES.LOLLIPOP ?
NotificationColorUtil.getInstance(mContext) : null;
}
diff --git a/core/java/android/content/Context.java b/core/java/android/content/Context.java
index 4e2aca0..c9b7d0a 100644
--- a/core/java/android/content/Context.java
+++ b/core/java/android/content/Context.java
@@ -3065,11 +3065,11 @@ public abstract class Context {
* "content://foo". It will not remove any prefix grants that exist at a
* higher level.
*
- * <p>Prior to {@link android.os.Build.VERSION_CODES#L}, if you did not have
+ * <p>Prior to {@link android.os.Build.VERSION_CODES#LOLLIPOP}, if you did not have
* regular permission access to a Uri, but had received access to it through
* a specific Uri permission grant, you could not revoke that grant with this
* function and a {@link SecurityException} would be thrown. As of
- * {@link android.os.Build.VERSION_CODES#L}, this function will not throw a security exception,
+ * {@link android.os.Build.VERSION_CODES#LOLLIPOP}, this function will not throw a security exception,
* but will remove whatever permission grants to the Uri had been given to the app
* (or none).</p>
*
diff --git a/core/java/android/content/Intent.java b/core/java/android/content/Intent.java
index 77981f4..af6f181 100644
--- a/core/java/android/content/Intent.java
+++ b/core/java/android/content/Intent.java
@@ -2226,7 +2226,7 @@ public class Intent implements Parcelable, Cloneable {
* Same as {@link android.media.AudioManager#ACTION_HEADSET_PLUG}, to be consulted for value
* and documentation.
* <p>If the minimum SDK version of your application is
- * {@link android.os.Build.VERSION_CODES#L}, it is recommended to refer
+ * {@link android.os.Build.VERSION_CODES#LOLLIPOP}, it is recommended to refer
* to the <code>AudioManager</code> constant in your receiver registration code instead.
*/
@SdkConstant(SdkConstantType.BROADCAST_INTENT_ACTION)
diff --git a/core/java/android/hardware/location/GeofenceHardware.java b/core/java/android/hardware/location/GeofenceHardware.java
index 7dd105a..f537a77 100644
--- a/core/java/android/hardware/location/GeofenceHardware.java
+++ b/core/java/android/hardware/location/GeofenceHardware.java
@@ -490,7 +490,7 @@ public final class GeofenceHardware {
// and only call the updated callback on on L and above, this complies with the
// documentation of GeofenceHardwareMonitorCallback
- if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.L) {
+ if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.LOLLIPOP) {
c.onMonitoringSystemChange(event);
}
}
diff --git a/core/java/android/os/Build.java b/core/java/android/os/Build.java
index 09b0a8b..ff194c5 100644
--- a/core/java/android/os/Build.java
+++ b/core/java/android/os/Build.java
@@ -485,7 +485,7 @@ public class Build {
public static final int JELLY_BEAN = 16;
/**
- * Android 4.2: Moar jelly beans!
+ * November 2012: Android 4.2, Moar jelly beans!
*
* <p>Applications targeting this or a later release will get these
* new changes in behavior:</p>
@@ -505,12 +505,12 @@ public class Build {
public static final int JELLY_BEAN_MR1 = 17;
/**
- * Android 4.3: Jelly Bean MR2, the revenge of the beans.
+ * July 2013: Android 4.3, the revenge of the beans.
*/
public static final int JELLY_BEAN_MR2 = 18;
/**
- * Android 4.4: KitKat, another tasty treat.
+ * October 2013: Android 4.4, KitKat, another tasty treat.
*
* <p>Applications targeting this or a later release will get these
* new changes in behavior:</p>
@@ -554,7 +554,12 @@ public class Build {
public static final int KITKAT_WATCH = 20;
/**
- * L!
+ * Temporary until we completely switch to {@link #LOLLIPOP}.
+ */
+ public static final int L = 21;
+
+ /**
+ * Lollipop. A flat one with beautiful shadows. But still tasty.
*
* <p>Applications targeting this or a later release will get these
* new changes in behavior:</p>
@@ -564,7 +569,7 @@ public class Build {
* Intent.</li>
* </ul>
*/
- public static final int L = 21;
+ public static final int LOLLIPOP = 21;
}
/** The type of build, like "user" or "eng". */
diff --git a/core/java/android/os/Message.java b/core/java/android/os/Message.java
index b6b70cc..6a0bddc 100644
--- a/core/java/android/os/Message.java
+++ b/core/java/android/os/Message.java
@@ -260,7 +260,7 @@ public final class Message implements Parcelable {
/** @hide */
public static void updateCheckRecycle(int targetSdkVersion) {
- if (targetSdkVersion < Build.VERSION_CODES.L) {
+ if (targetSdkVersion < Build.VERSION_CODES.LOLLIPOP) {
gCheckRecycle = false;
}
}
diff --git a/core/java/android/os/UserManager.java b/core/java/android/os/UserManager.java
index 984f12f..1368f39 100644
--- a/core/java/android/os/UserManager.java
+++ b/core/java/android/os/UserManager.java
@@ -19,7 +19,6 @@ import android.annotation.SystemApi;
import android.app.ActivityManager;
import android.app.ActivityManagerNative;
import android.content.Context;
-import android.content.pm.PackageManager;
import android.content.pm.UserInfo;
import android.content.res.Resources;
import android.graphics.Bitmap;
@@ -434,7 +433,7 @@ public class UserManager {
* Used to determine whether the user making this call is subject to
* teleportations.
*
- * <p>As of {@link android.os.Build.VERSION_CODES#L}, this method can
+ * <p>As of {@link android.os.Build.VERSION_CODES#LOLLIPOP}, this method can
* now automatically identify goats using advanced goat recognition technology.</p>
*
* @return Returns true if the user making this call is a goat.
diff --git a/core/java/android/provider/MediaStore.java b/core/java/android/provider/MediaStore.java
index d137f0c..736ec54 100644
--- a/core/java/android/provider/MediaStore.java
+++ b/core/java/android/provider/MediaStore.java
@@ -256,7 +256,7 @@ public final class MediaStore {
* object in the extra field. This is useful for applications that only need a small image.
* If the EXTRA_OUTPUT is present, then the full-sized image will be written to the Uri
* value of EXTRA_OUTPUT.
- * As of {@link android.os.Build.VERSION_CODES#L}, this uri can also be supplied through
+ * As of {@link android.os.Build.VERSION_CODES#LOLLIPOP}, this uri can also be supplied through
* {@link android.content.Intent#setClipData(ClipData)}. If using this approach, you still must
* supply the uri through the EXTRA_OUTPUT field for compatibility with old applications.
* If you don't set a ClipData, it will be copied there for you when calling
@@ -281,7 +281,7 @@ public final class MediaStore {
* object in the extra field. This is useful for applications that only need a small image.
* If the EXTRA_OUTPUT is present, then the full-sized image will be written to the Uri
* value of EXTRA_OUTPUT.
- * As of {@link android.os.Build.VERSION_CODES#L}, this uri can also be supplied through
+ * As of {@link android.os.Build.VERSION_CODES#LOLLIPOP}, this uri can also be supplied through
* {@link android.content.Intent#setClipData(ClipData)}. If using this approach, you still must
* supply the uri through the EXTRA_OUTPUT field for compatibility with old applications.
* If you don't set a ClipData, it will be copied there for you when calling
@@ -304,7 +304,7 @@ public final class MediaStore {
* where the video is written. If EXTRA_OUTPUT is not present the video will be
* written to the standard location for videos, and the Uri of that location will be
* returned in the data field of the Uri.
- * As of {@link android.os.Build.VERSION_CODES#L}, this uri can also be supplied through
+ * As of {@link android.os.Build.VERSION_CODES#LOLLIPOP}, this uri can also be supplied through
* {@link android.content.Intent#setClipData(ClipData)}. If using this approach, you still must
* supply the uri through the EXTRA_OUTPUT field for compatibility with old applications.
* If you don't set a ClipData, it will be copied there for you when calling
diff --git a/core/java/android/service/notification/NotificationListenerService.java b/core/java/android/service/notification/NotificationListenerService.java
index 5d6acd8..3d39b18 100644
--- a/core/java/android/service/notification/NotificationListenerService.java
+++ b/core/java/android/service/notification/NotificationListenerService.java
@@ -268,9 +268,9 @@ public abstract class NotificationListenerService extends Service {
* {@link android.app.NotificationManager#notify(String, int, android.app.Notification)}.
* <p>
* @deprecated Use {@link #cancelNotification(String key)}
- * instead. Beginning with {@link android.os.Build.VERSION_CODES#L} this method will no longer
+ * instead. Beginning with {@link android.os.Build.VERSION_CODES#LOLLIPOP} this method will no longer
* cancel the notification. It will continue to cancel the notification for applications
- * whose {@code targetSdkVersion} is earlier than {@link android.os.Build.VERSION_CODES#L}.
+ * whose {@code targetSdkVersion} is earlier than {@link android.os.Build.VERSION_CODES#LOLLIPOP}.
*/
public final void cancelNotification(String pkg, String tag, int id) {
if (!isBound()) return;
diff --git a/core/java/android/view/WindowManagerGlobal.java b/core/java/android/view/WindowManagerGlobal.java
index dffcca4..5926d5f 100644
--- a/core/java/android/view/WindowManagerGlobal.java
+++ b/core/java/android/view/WindowManagerGlobal.java
@@ -211,7 +211,7 @@ public final class WindowManagerGlobal {
// system context), assume we want hardware acceleration.
final Context context = view.getContext();
if (context != null
- && context.getApplicationInfo().targetSdkVersion >= Build.VERSION_CODES.L) {
+ && context.getApplicationInfo().targetSdkVersion >= Build.VERSION_CODES.LOLLIPOP) {
wparams.flags |= WindowManager.LayoutParams.FLAG_HARDWARE_ACCELERATED;
}
}
diff --git a/core/java/android/webkit/CookieManager.java b/core/java/android/webkit/CookieManager.java
index de7d2d0..20ef646 100644
--- a/core/java/android/webkit/CookieManager.java
+++ b/core/java/android/webkit/CookieManager.java
@@ -17,7 +17,6 @@
package android.webkit;
import android.net.WebAddress;
-import android.webkit.ValueCallback;
/**
* Manages the cookies used by an application's {@link WebView} instances.
@@ -81,7 +80,7 @@ public class CookieManager {
* <p>
* Apps that target {@link android.os.Build.VERSION_CODES#KITKAT} or below
* default to allowing third party cookies. Apps targeting
- * {@link android.os.Build.VERSION_CODES#L} or later default to disallowing
+ * {@link android.os.Build.VERSION_CODES#LOLLIPOP} or later default to disallowing
* third party cookies.
*
* @param webview the {@link WebView} instance to set the cookie policy on
diff --git a/core/java/android/webkit/WebSettings.java b/core/java/android/webkit/WebSettings.java
index 6d7c803..db8fc6f 100644
--- a/core/java/android/webkit/WebSettings.java
+++ b/core/java/android/webkit/WebSettings.java
@@ -1461,7 +1461,7 @@ public abstract class WebSettings {
*
* By default, apps that target {@link android.os.Build.VERSION_CODES#KITKAT} or below default
* to {@link #MIXED_CONTENT_ALWAYS_ALLOW}. Apps targeting
- * {@link android.os.Build.VERSION_CODES#L} default to {@link #MIXED_CONTENT_NEVER_ALLOW}.
+ * {@link android.os.Build.VERSION_CODES#LOLLIPOP} default to {@link #MIXED_CONTENT_NEVER_ALLOW}.
*
* The preferred and most secure mode of operation for the WebView is
* {@link #MIXED_CONTENT_NEVER_ALLOW} and use of {@link #MIXED_CONTENT_ALWAYS_ALLOW} is
@@ -1482,7 +1482,7 @@ public abstract class WebSettings {
/**
* Sets whether to use a video overlay for embedded encrypted video.
- * In API levels prior to {@link android.os.Build.VERSION_CODES#L}, encrypted video can
+ * In API levels prior to {@link android.os.Build.VERSION_CODES#LOLLIPOP}, encrypted video can
* only be rendered directly on a secure video surface, so it had been a hard problem to play
* encrypted video in HTML. When this flag is on, WebView can play encrypted video (MSE/EME)
* by using a video overlay (aka hole-punching) for videos embedded using HTML &lt;video&gt;
diff --git a/core/java/android/webkit/WebView.java b/core/java/android/webkit/WebView.java
index 68f5dad..592d6e2 100644
--- a/core/java/android/webkit/WebView.java
+++ b/core/java/android/webkit/WebView.java
@@ -25,7 +25,6 @@ import android.graphics.Paint;
import android.graphics.Picture;
import android.graphics.Rect;
import android.graphics.drawable.Drawable;
-import android.net.Uri;
import android.net.http.SslCertificate;
import android.os.Build;
import android.os.Bundle;
@@ -1754,7 +1753,7 @@ public class WebView extends AbsoluteLayout
* safety.
* </li>
* <li> The Java object's fields are not accessible.</li>
- * <li> For applications targeted to API level {@link android.os.Build.VERSION_CODES#L}
+ * <li> For applications targeted to API level {@link android.os.Build.VERSION_CODES#LOLLIPOP}
* and above, methods of injected Java objects are enumerable from
* JavaScript.</li>
* </ul>
diff --git a/core/java/android/widget/Editor.java b/core/java/android/widget/Editor.java
index 128a06c..936da32 100644
--- a/core/java/android/widget/Editor.java
+++ b/core/java/android/widget/Editor.java
@@ -82,7 +82,6 @@ import android.view.RenderNode;
import android.view.DragEvent;
import android.view.Gravity;
import android.view.HardwareCanvas;
-import android.view.HardwareRenderer;
import android.view.LayoutInflater;
import android.view.Menu;
import android.view.MenuItem;
@@ -2793,7 +2792,7 @@ public class Editor {
@Override
public boolean onCreateActionMode(ActionMode mode, Menu menu) {
final boolean legacy = mTextView.getContext().getApplicationInfo().targetSdkVersion <
- Build.VERSION_CODES.L;
+ Build.VERSION_CODES.LOLLIPOP;
final Context context = !legacy && menu instanceof MenuBuilder ?
((MenuBuilder) menu).getContext() :
mTextView.getContext();
diff --git a/core/java/com/android/internal/app/ResolverActivity.java b/core/java/com/android/internal/app/ResolverActivity.java
index 5685ad7..aa55d23 100644
--- a/core/java/com/android/internal/app/ResolverActivity.java
+++ b/core/java/com/android/internal/app/ResolverActivity.java
@@ -25,7 +25,6 @@ import android.provider.Settings;
import android.text.TextUtils;
import android.util.Slog;
import android.widget.AbsListView;
-import android.widget.GridView;
import com.android.internal.R;
import com.android.internal.content.PackageMonitor;
@@ -487,7 +486,7 @@ public class ResolverActivity extends Activity implements AdapterView.OnItemClic
}
private boolean versionNumberAtLeastL(int versionNumber) {
- return versionNumber >= Build.VERSION_CODES.L;
+ return versionNumber >= Build.VERSION_CODES.LOLLIPOP;
}
private void setAlwaysButtonEnabled(boolean hasValidSelection, int checkedPos,
diff --git a/graphics/java/android/graphics/BitmapFactory.java b/graphics/java/android/graphics/BitmapFactory.java
index eda1a5d..da58884 100644
--- a/graphics/java/android/graphics/BitmapFactory.java
+++ b/graphics/java/android/graphics/BitmapFactory.java
@@ -260,7 +260,7 @@ public class BitmapFactory {
public boolean inScaled;
/**
- * @deprecated As of {@link android.os.Build.VERSION_CODES#L}, this is
+ * @deprecated As of {@link android.os.Build.VERSION_CODES#LOLLIPOP}, this is
* ignored.
*
* In {@link android.os.Build.VERSION_CODES#KITKAT} and below, if this
@@ -295,7 +295,7 @@ public class BitmapFactory {
public boolean inPurgeable;
/**
- * @deprecated As of {@link android.os.Build.VERSION_CODES#L}, this is
+ * @deprecated As of {@link android.os.Build.VERSION_CODES#LOLLIPOP}, this is
* ignored.
*
* In {@link android.os.Build.VERSION_CODES#KITKAT} and below, this
diff --git a/graphics/java/android/graphics/Picture.java b/graphics/java/android/graphics/Picture.java
index d28c3d5..fa9af2a 100644
--- a/graphics/java/android/graphics/Picture.java
+++ b/graphics/java/android/graphics/Picture.java
@@ -111,7 +111,7 @@ public class Picture {
/**
* Draw this picture on the canvas.
* <p>
- * Prior to {@link android.os.Build.VERSION_CODES#L}, this call could
+ * Prior to {@link android.os.Build.VERSION_CODES#LOLLIPOP}, this call could
* have the side effect of changing the matrix and clip of the canvas
* if this picture had imbalanced saves/restores.
*
diff --git a/graphics/java/android/graphics/drawable/ColorDrawable.java b/graphics/java/android/graphics/drawable/ColorDrawable.java
index 0608065..1253c46 100644
--- a/graphics/java/android/graphics/drawable/ColorDrawable.java
+++ b/graphics/java/android/graphics/drawable/ColorDrawable.java
@@ -157,7 +157,7 @@ public class ColorDrawable extends Drawable {
/**
* Sets the color filter applied to this color.
* <p>
- * Only supported on version {@link android.os.Build.VERSION_CODES#L} and
+ * Only supported on version {@link android.os.Build.VERSION_CODES#LOLLIPOP} and
* above. Calling this method has no effect on earlier versions.
*
* @see android.graphics.drawable.Drawable#setColorFilter(ColorFilter)
diff --git a/location/java/android/location/LocationManager.java b/location/java/android/location/LocationManager.java
index 0445869..ed408e0 100644
--- a/location/java/android/location/LocationManager.java
+++ b/location/java/android/location/LocationManager.java
@@ -1112,7 +1112,7 @@ public class LocationManager {
* {@link #requestLocationUpdates(String, long, float, LocationListener)}.
*
* <p>
- * Before API version {@link android.os.Build.VERSION_CODES#L}, this
+ * Before API version {@link android.os.Build.VERSION_CODES#LOLLIPOP}, this
* method would throw {@link SecurityException} if the location permissions
* were not sufficient to use the specified provider.
*
diff --git a/packages/SystemUI/src/com/android/systemui/statusbar/BaseStatusBar.java b/packages/SystemUI/src/com/android/systemui/statusbar/BaseStatusBar.java
index eef4a5a..9492a14 100644
--- a/packages/SystemUI/src/com/android/systemui/statusbar/BaseStatusBar.java
+++ b/packages/SystemUI/src/com/android/systemui/statusbar/BaseStatusBar.java
@@ -696,7 +696,7 @@ public abstract class BaseStatusBar extends SystemUI implements
if (entry.expanded.getId() != com.android.internal.R.id.status_bar_latest_event_content) {
// Using custom RemoteViews
if (entry.targetSdk >= Build.VERSION_CODES.GINGERBREAD
- && entry.targetSdk < Build.VERSION_CODES.L) {
+ && entry.targetSdk < Build.VERSION_CODES.LOLLIPOP) {
entry.row.setShowingLegacyBackground(true);
entry.legacy = true;
}
@@ -712,7 +712,7 @@ public abstract class BaseStatusBar extends SystemUI implements
}
if (entry.icon != null) {
- if (entry.targetSdk >= Build.VERSION_CODES.L) {
+ if (entry.targetSdk >= Build.VERSION_CODES.LOLLIPOP) {
entry.icon.setColorFilter(mContext.getResources().getColor(android.R.color.white));
} else {
entry.icon.setColorFilter(null);
@@ -1385,7 +1385,7 @@ public abstract class BaseStatusBar extends SystemUI implements
Drawable iconDrawable = StatusBarIconView.getIcon(mContext, ic);
icon.setImageDrawable(iconDrawable);
- if (entry.targetSdk >= Build.VERSION_CODES.L
+ if (entry.targetSdk >= Build.VERSION_CODES.LOLLIPOP
|| mNotificationColorUtil.isGrayscaleIcon(iconDrawable)) {
icon.setBackgroundResource(
com.android.internal.R.drawable.notification_icon_legacy_bg);
diff --git a/policy/src/com/android/internal/policy/impl/PhoneWindow.java b/policy/src/com/android/internal/policy/impl/PhoneWindow.java
index 5f3b877..e9a114a 100644
--- a/policy/src/com/android/internal/policy/impl/PhoneWindow.java
+++ b/policy/src/com/android/internal/policy/impl/PhoneWindow.java
@@ -3334,7 +3334,7 @@ public class PhoneWindow extends Window implements MenuBuilder.Callback {
final int targetSdk = context.getApplicationInfo().targetSdkVersion;
final boolean targetPreHoneycomb = targetSdk < android.os.Build.VERSION_CODES.HONEYCOMB;
final boolean targetPreIcs = targetSdk < android.os.Build.VERSION_CODES.ICE_CREAM_SANDWICH;
- final boolean targetPreL = targetSdk < android.os.Build.VERSION_CODES.L;
+ final boolean targetPreL = targetSdk < android.os.Build.VERSION_CODES.LOLLIPOP;
final boolean targetHcNeedsOptions = context.getResources().getBoolean(
R.bool.target_honeycomb_needs_options_menu);
final boolean noActionBar = !hasFeature(FEATURE_ACTION_BAR) || hasFeature(FEATURE_NO_TITLE);
diff --git a/services/core/java/com/android/server/am/ActiveServices.java b/services/core/java/com/android/server/am/ActiveServices.java
index f430c56..0b253f5 100755
--- a/services/core/java/com/android/server/am/ActiveServices.java
+++ b/services/core/java/com/android/server/am/ActiveServices.java
@@ -31,7 +31,6 @@ import android.os.Looper;
import android.os.SystemProperties;
import android.util.ArrayMap;
import android.util.ArraySet;
-import com.android.internal.app.ProcessMap;
import com.android.internal.app.ProcessStats;
import com.android.internal.os.BatteryStatsImpl;
import com.android.internal.os.TransferPipe;
@@ -591,7 +590,7 @@ public final class ActiveServices {
r.cancelNotification();
r.foregroundId = 0;
r.foregroundNoti = null;
- } else if (r.appInfo.targetSdkVersion >= Build.VERSION_CODES.L) {
+ } else if (r.appInfo.targetSdkVersion >= Build.VERSION_CODES.LOLLIPOP) {
r.stripForegroundServiceFlagFromNotification();
}
}
diff --git a/services/core/java/com/android/server/dreams/DreamManagerService.java b/services/core/java/com/android/server/dreams/DreamManagerService.java
index 985f77a..4521c28 100644
--- a/services/core/java/com/android/server/dreams/DreamManagerService.java
+++ b/services/core/java/com/android/server/dreams/DreamManagerService.java
@@ -262,7 +262,7 @@ public final class DreamManagerService extends SystemService {
if (serviceInfo == null) {
Slog.w(TAG, "Dream " + component + " does not exist");
return false;
- } else if (serviceInfo.applicationInfo.targetSdkVersion >= Build.VERSION_CODES.L
+ } else if (serviceInfo.applicationInfo.targetSdkVersion >= Build.VERSION_CODES.LOLLIPOP
&& !BIND_DREAM_SERVICE.equals(serviceInfo.permission)) {
Slog.w(TAG, "Dream " + component
+ " is not available because its manifest is missing the " + BIND_DREAM_SERVICE
diff --git a/services/core/java/com/android/server/notification/ManagedServices.java b/services/core/java/com/android/server/notification/ManagedServices.java
index 13fbf6c..0c7d71b 100644
--- a/services/core/java/com/android/server/notification/ManagedServices.java
+++ b/services/core/java/com/android/server/notification/ManagedServices.java
@@ -496,7 +496,7 @@ abstract public class ManagedServices {
synchronized (mMutex) {
try {
ManagedServiceInfo info = newServiceInfo(service, component, userid,
- true /*isSystem*/, null, Build.VERSION_CODES.L);
+ true /*isSystem*/, null, Build.VERSION_CODES.LOLLIPOP);
service.asBinder().linkToDeath(info, 0);
mServices.add(info);
return info;
@@ -585,7 +585,7 @@ abstract public class ManagedServices {
}
public boolean supportsProfiles() {
- return targetSdkVersion >= Build.VERSION_CODES.L;
+ return targetSdkVersion >= Build.VERSION_CODES.LOLLIPOP;
}
@Override
diff --git a/core/java/android/widget/Spinner.java b/core/java/android/widget/Spinner.java
index 98d52ff..0d76239 100644
--- a/core/java/android/widget/Spinner.java
+++ b/core/java/android/widget/Spinner.java
@@ -417,7 +417,7 @@ public class Spinner extends AbsSpinner implements OnClickListener {
* {@link Adapter#getItemViewType(int) getItemViewType(int)} on the object
* returned from {@link #getAdapter()} will always return 0. Calling
* {@link Adapter#getViewTypeCount() getViewTypeCount()} will always return
* 1. On API {@link Build.VERSION_CODES#L} and above, attempting to set an
* adapter with more than one view type will throw an
* {@link IllegalArgumentException}.
*
@@ -434,7 +434,7 @@ public class Spinner extends AbsSpinner implements OnClickListener {
mRecycler.clear();
final int targetSdkVersion = mContext.getApplicationInfo().targetSdkVersion;
- if (targetSdkVersion >= Build.VERSION_CODES.L
+ if (targetSdkVersion >= Build.VERSION_CODES.LOLLIPOP
&& adapter != null && adapter.getViewTypeCount() != 1) {
throw new IllegalArgumentException("Spinner adapter view type count must be 1");
}
@@ -417,7 +417,7 @@ public class Spinner extends AbsSpinner implements OnClickListener {
* returned from {@link #getAdapter()} will always return 0. Calling
* {@link Adapter#getViewTypeCount() getViewTypeCount()} will always return
- * 1. On API {@link Build.VERSION_CODES#L} and above, attempting to set an
+ * 1. On API {@link Build.VERSION_CODES#LOLLIPOP} and above, attempting to set an
* adapter with more than one view type will throw an
* {@link IllegalArgumentException}.